function garchOut = garchModel(THETA, y, yhat, DATA, UT, LT)
%
% Estimate a GARCH(1,1) model (with robust standard errors and LB statistics) and computes the various risk indices.
% INPUT: THETA = (1,2) vector with the probabilities associated with IaR and DaR.
%        y     = vector of residuals from the regression model
%        yhat  = OLS regression estimates 
%        DATA = indicator variable for the current data set

T = length(y);

% Run the garch model.
f = garch(y);

param = f.theta;
stdErr = sqrt(f.variance); variance = f.variance;
VAR4cast = [1, variance(T), y(T)^2] * param;

% *************************************************************************
% STEP 1 - Specification tests for the GARCH model.
% 1. Compute standard errors.
rse = garch11robustStdErr(param, y);
stdRes = y./stdErr;

% 2. Ljung-Box statistic.
[LBstd, LBpvaluestd] = LjungBox(stdRes);
[LBstd2, LBpvaluestd2] = LjungBox(stdRes.^2);

% *************************************************************************
% STEP 2 - Compute inflation and deflation risks.

for i = 1:T
    index1 = find(stdRes<(LT-yhat(i))/stdErr(i));
    index2 = find(stdRes>(UT-yhat(i))/stdErr(i));
    
    if isempty(index1), PD=0; DR(i,1)=0;
    else PD=length(index1)/length(yhat);
        DR1(i,1)=PD*(yhat(i)-LT+stdErr(i)*mean(stdRes(index1)));
        DR2(i,1)=-PD*((yhat(i)-LT)^2+(stdErr(i)^2)*(mean(stdRes(index1).^2))+2*(yhat(i)-LT)*stdErr(i)*mean(stdRes(index1)));
    end
    
    if isempty(index2), PEI=0; EIR(i,1)=0; 
    else PEI=length(index2)/length(yhat); 
        EIR1(i,1)=PEI*(yhat(i)-UT+stdErr(i)*mean(stdRes(index2)));
        EIR2(i,1)=PEI*((yhat(i)-UT)^2+(stdErr(i)^2)*(mean(stdRes(index2).^2))+2*(yhat(i)-UT)*stdErr(i)*mean(stdRes(index2)));
    end
    
end

garchOut.param = param;
garchOut.rse = rse;
garchOut.LBstd = LBstd;
garchOut.LBpvaluestd = LBpvaluestd;
garchOut.LBstd2 = LBstd2;
garchOut.LBpvaluestd2 = LBpvaluestd2;
garchOut.DR1 = DR1;
garchOut.DR2 = DR2;
garchOut.EIR1 = EIR1;
garchOut.EIR2 = EIR2;
